#!/usr/bin/env python3

import os

import fastnlo as fnlo

TYPES = ["fix", "flex"]
NAMES = ["NodesPerBin", "NodeDensity"]
SEEDS = [1000, 2000]

# fnlo.SetGlobalVerbosity(fnlo.DEBUG)

os.system("rm -rf output")


def generate_table(vartype: str, name: str, seed: int):
    os.system(f"ln -sf {vartype}_{name}.str InclusiveNJets.str")
    os.system(
        "nlojet++ "
        "--calculate "
        "-c born "
        f"-s {seed} "
        f"--name {vartype}_{name}_{seed:06d} "
        " -u /usr/lib/fastnlo_interface_nlojet/libInclusiveNJets.la "
        "--max-event 100000 "
        "--save-after 100000 "
    )
    os.system(f"mv output/run-hhc-born-2jet.tab.gz output/{vartype}_{name}_{seed:06d}.tab.gz")


for vartype in TYPES:
    for steering_file in NAMES:
        for seed in SEEDS:
            generate_table(vartype, steering_file, seed)
        os.system(f"fnlo-tk-merge2 output/{vartype}_{steering_file}_??????.tab.gz "
                  f"output/{vartype}_{steering_file}_merged.tab.gz")

    for seed in SEEDS:
        filename_0 = f"output/{vartype}_{NAMES[0]}_{seed:06d}.tab.gz"
        filename_1 = f"output/{vartype}_{NAMES[1]}_{seed:06d}.tab.gz"
        table_0 = fnlo.fastNLOTable(filename_0)
        table_1 = fnlo.fastNLOTable(filename_1)
        print(f"Asserting equal: {filename_0} <-> {filename_1}")
        assert table_0.IsEquivalent(table_1, 1e-8)

    filename_0 = f"output/{vartype}_{NAMES[0]}_merged.tab.gz"
    filename_1 = f"output/{vartype}_{NAMES[1]}_merged.tab.gz"
    table_0_merged = fnlo.fastNLOTable(filename_0)
    table_1_merged = fnlo.fastNLOTable(filename_1)
    print(f"Asserting equal: {filename_0} <-> {filename_1}")
    assert table_0_merged.IsEquivalent(table_1_merged, 1e-8)
